This package is an alias package for [jupyterlab-stickyland](https://pypi.org/project/jupyterlab-stickyland/)

See this [pypi page]((https://pypi.org/project/jupyterlab-stickyland/) for more information: https://pypi.org/project/jupyterlab-stickyland/
